<script setup lang="ts">
import {defineComponent, PropType} from "vue";
import { QueueVO } from '@/api/ecg/queue'
import {DICT_TYPE} from "@/utils/dict";
import {PatientVO, DoctorApi} from "@/api/ecg/doctor";
import {useCheckTypeStore} from "@/store/modules/checkType";

defineComponent({
  name: 'QueuePanel'
})

const emit = defineEmits(['event_RecallFinish']) // 定义 success 事件，用于操作成功后的回调

const checkTypeStore = useCheckTypeStore();

const message = useMessage() // 消息弹窗

const  props = defineProps({
  queue: {
    type: Array as PropType<QueueVO[]>,
    required: true
  }
  /*,
  modelValue: {
    type: Object as PropType<RoomVO>,
    required: true
  }
*/
})

const recall = async (item) => {
  const patientVO: PatientVO = {
    roomId: item.roomId,
    bedNo: item.bedNo,
    patId: item.patId,
    jumpFlag: 0
  }

  let data = ""
  if (item.status === 5) // 常规、领用 过号
    data = await DoctorApi.recallPatient(patientVO);
  else if (item.status === 7)
    data = await DoctorApi.recallInstallPatient(patientVO);

  emit("event_RecallFinish") // 装机 过号
  message.info(data)
}

</script>

<template>
<div v-for="(item, index) in queue" :key="index">
  <span style="display:inline-block; width:100px;"> {{item.seqNum}} &nbsp; {{item.patName}}{{item.passed === 0 ? "":"*"}} </span>
  <dict-tag :type="DICT_TYPE.SYSTEM_USER_SEX" :value="item.patGender" />
<!--  {{item.roomName}} {{item.bedNo}}-->
  {{checkTypeStore.getCheckTypeName(item.bookCheckType)}}
  <dict-tag :type="DICT_TYPE.ECG_QUEUE_STATUS" :value="item.status" />
  <el-button v-if="item.status === 5 || item.status === 7" @click="recall(item)"> 召回 </el-button>
</div>
</template>

<style scoped lang="scss">
div {
  padding-left: 5px;
  padding-bottom: 5px;
}

</style>
